summaryrefslogtreecommitdiffstats
path: root/karbon/core/vselection.h
diff options
context:
space:
mode:
Diffstat (limited to 'karbon/core/vselection.h')
-rw-r--r--karbon/core/vselection.h16
1 files changed, 8 insertions, 8 deletions
diff --git a/karbon/core/vselection.h b/karbon/core/vselection.h
index 31dbb266..c98e5bf1 100644
--- a/karbon/core/vselection.h
+++ b/karbon/core/vselection.h
@@ -22,7 +22,7 @@
#define __VSELECTION_H__
-#include <qptrlist.h>
+#include <tqptrlist.h>
#include <KoRect.h>
@@ -30,13 +30,13 @@
#include "vvisitor.h"
#include <koffice_export.h>
class KoPoint;
-class QObject;
+class TQObject;
class VPainter;
class VVisitor;
class VSegment;
-typedef QPtrList<VObject> VObjectList;
-typedef QPtrListIterator<VObject> VObjectListIterator;
+typedef TQPtrList<VObject> VObjectList;
+typedef TQPtrListIterator<VObject> VObjectListIterator;
/// Ids of manipulation nodes.
@@ -62,11 +62,11 @@ class KARBONBASE_EXPORT VSelection : public VObject, public VVisitor
{
public:
/**
* Constructs a vselection with the specified parent.
*
* @param parent the selection's parent
*/
- VSelection( VObject* parent = 0L );
+ VSelection( VObject* tqparent = 0L );
/**
* Constructs a vselection by copying the specified selection.
@@ -141,7 +141,7 @@ public:
* @param rect the selection rect
* @return the list of segments
*/
- QPtrList<VSegment> getSegments( const KoRect& rect );
+ TQPtrList<VSegment> getSegments( const KoRect& rect );
/**
* Selects or deselects all nodes.
@@ -62,11 +62,11 @@ class KARBONBASE_EXPORT VSelection : public VObject, public VVisitor
public:
/**
- * Constructs a vselection with the specified parent.
+ * Constructs a vselection with the specified tqparent.
*
@@ -62,11 +62,11 @@ class KARBONBASE_EXPORT VSelection : public VObject, public VVisitor
*
- * @param parent the selection's parent
+ * @param tqparent the selection's tqparent
*/